From: David Wang <david.w...@arm.com>

In the latest changes of optee_os, the interrupts' names are
changed to "native" and "foreign" interrupts.

Signed-off-by: David Wang <david.w...@arm.com>
Signed-off-by: Jerome Forissier <jerome.foriss...@linaro.org>
Signed-off-by: Jens Wiklander <jens.wiklan...@linaro.org>
---
 drivers/tee/optee/optee_smc.h | 12 ++++++------
 drivers/tee/optee/rpc.c       |  8 ++++----
 2 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/drivers/tee/optee/optee_smc.h b/drivers/tee/optee/optee_smc.h
index 13b7c98cdf25..069c8e1429de 100644
--- a/drivers/tee/optee/optee_smc.h
+++ b/drivers/tee/optee/optee_smc.h
@@ -298,7 +298,7 @@ struct optee_smc_disable_shm_cache_result {
        OPTEE_SMC_FAST_CALL_VAL(OPTEE_SMC_FUNCID_ENABLE_SHM_CACHE)
 
 /*
  * Resume from RPC (for example after processing an IRQ)
  *
  * Call register usage:
  * a0  SMC Function ID, OPTEE_SMC_CALL_RETURN_FROM_RPC
@@ -383,19 +383,19 @@ struct optee_smc_disable_shm_cache_result {
        OPTEE_SMC_RPC_VAL(OPTEE_SMC_RPC_FUNC_FREE)
 
 /*
  * Deliver an IRQ in normal world.
  *
  * "Call" register usage:
- * a0  OPTEE_SMC_RETURN_RPC_IRQ
+ * a0  OPTEE_SMC_RETURN_RPC_FOREIGN_INTR
  * a1-7        Resume information, must be preserved
  *
  * "Return" register usage:
  * a0  SMC Function ID, OPTEE_SMC_CALL_RETURN_FROM_RPC.
  * a1-7        Preserved
  */
-#define OPTEE_SMC_RPC_FUNC_IRQ         4
-#define OPTEE_SMC_RETURN_RPC_IRQ \
-       OPTEE_SMC_RPC_VAL(OPTEE_SMC_RPC_FUNC_IRQ)
+#define OPTEE_SMC_RPC_FUNC_FOREIGN_INTR                4
+#define OPTEE_SMC_RETURN_RPC_FOREIGN_INTR \
+       OPTEE_SMC_RPC_VAL(OPTEE_SMC_RPC_FUNC_FOREIGN_INTR)
 
 /*
  * Do an RPC request. The supplied struct optee_msg_arg tells which
@@ -298,7 +298,7 @@ struct optee_smc_disable_shm_cache_result {
 
 /*
- * Resume from RPC (for example after processing an IRQ)
+ * Resume from RPC (for example after processing a foreign interrupt)
  *
  * Call register usage:
@@ -383,19 +383,19 @@ struct optee_smc_disable_shm_cache_result {
 
 /*
- * Deliver an IRQ in normal world.
+ * Deliver foreign interrupt to normal world.
  *
  * "Call" register usage:
diff --git a/drivers/tee/optee/rpc.c b/drivers/tee/optee/rpc.c
index 9488ed1541bc..cef417f4f4d2 100644
--- a/drivers/tee/optee/rpc.c
+++ b/drivers/tee/optee/rpc.c
@@ -371,11 +371,11 @@ void optee_handle_rpc(struct tee_context *ctx, struct 
optee_rpc_param *param)
                shm = reg_pair_to_ptr(param->a1, param->a2);
                tee_shm_free(shm);
                break;
-       case OPTEE_SMC_RPC_FUNC_IRQ:
+       case OPTEE_SMC_RPC_FUNC_FOREIGN_INTR:
                /*
                 * An IRQ was raised while secure world was executing,
                 * since all IRQs are handled in Linux a dummy RPC is
                 * performed to let Linux take the IRQ through the normal
                 * vector.
                 */
                break;
@@ -371,11 +371,11 @@ void optee_handle_rpc(struct tee_context *ctx, struct 
                /*
-                * An IRQ was raised while secure world was executing,
-                * since all IRQs are handled in Linux a dummy RPC is
-                * performed to let Linux take the IRQ through the normal
+                * A foreign interrupt was raised while secure world was
+                * executing, since they are handled in Linux a dummy RPC is
+                * performed to let Linux take the interrupt through the normal
                 * vector.
                 */
-- 
2.7.4

Reply via email to